pub struct Config(/* private fields */);Expand description
The yamux configuration.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn client() -> Self
👎Deprecated: Will be removed with the next breaking release.
pub fn client() -> Self
Creates a new YamuxConfig in client mode, regardless of whether
it will be used for an inbound or outbound upgrade.
Sourcepub fn server() -> Self
👎Deprecated: Will be removed with the next breaking release.
pub fn server() -> Self
Creates a new YamuxConfig in server mode, regardless of whether
it will be used for an inbound or outbound upgrade.
Sourcepub fn set_receive_window_size(&mut self, num_bytes: u32) -> &mut Self
👎Deprecated: Will be replaced in the next breaking release with a connection receive window size limit.
pub fn set_receive_window_size(&mut self, num_bytes: u32) -> &mut Self
Sets the size (in bytes) of the receive window per substream.
Sourcepub fn set_max_buffer_size(&mut self, num_bytes: usize) -> &mut Self
👎Deprecated: Will be removed with the next breaking release.
pub fn set_max_buffer_size(&mut self, num_bytes: usize) -> &mut Self
Sets the maximum size (in bytes) of the receive buffer per substream.
Sourcepub fn set_max_num_streams(&mut self, num_streams: usize) -> &mut Self
pub fn set_max_num_streams(&mut self, num_streams: usize) -> &mut Self
Sets the maximum number of concurrent substreams.
Sourcepub fn set_window_update_mode(&mut self, mode: WindowUpdateMode) -> &mut Self
👎Deprecated: WindowUpdate::OnRead is the default. WindowUpdate::OnReceive breaks backpressure, is thus not recommended, and will be removed in the next breaking release. Thus this method becomes obsolete and will be removed with the next breaking release.
pub fn set_window_update_mode(&mut self, mode: WindowUpdateMode) -> &mut Self
WindowUpdate::OnRead is the default. WindowUpdate::OnReceive breaks backpressure, is thus not recommended, and will be removed in the next breaking release. Thus this method becomes obsolete and will be removed with the next breaking release.Sets the window update mode that determines when the remote is given new credit for sending more data.